Model agnostic function to calculate a number of common performance
metrics on the reference time window.
Uses the true data value and the predictions prediction for this calculation.
The coverage is calculated from the columns value, prediction_lower and
prediction_upper.
Removes dates in the effect and buffer range as the model is not expected to
be performing correctly for these times. The incorrectness is precisely
what we are using for estimating the effect.
calc_performance_metrics(predictions, date_effect_start = NULL, buffer = 0)Named vector with performance metrics of the model
data.table or data.frame with the following columns
Date of the observation. Needs to be comparable to date_effect_start element.
True observed value of the station
Predicted model output for the same time and station as value
Lower end of the prediction interval
Upper end of the prediction interval
A date. Start date of the effect that is to be evaluated. The data from this point onwards is disregarded for calculating model performance
Integer. An additional buffer window before date_effect_start to account for uncertainty in the effect start point. Disregards additional buffer data points for model evaluation