Helps with analyzing predictions by comparing them with the true values on a number of relevant summary statistics.
calc_summary_statistics(predictions, date_effect_start = NULL, buffer = 0)data.frame of summary statistics with columns true and prediction
Data.table or data.frame with the following columns
Date of the observation. Needs to be comparable to date_effect_start element.
True observed value of the station
Predicted model output for the same time and station as value
A date. Start date of the effect that is to be evaluated. The data from this point onwards is disregarded for calculating model performance
Integer. An additional buffer window before date_effect_start to account for uncertainty in the effect start point. Disregards additional buffer data points for model evaluation