Learn R Programming

ubair (version 1.1.1)

get_meteo_available: Get Available Meteorological Components

Description

Identifies unique meteorological components from the provided environmental data, filtering only those that match the predefined UBA naming conventions. These components include "GLO", "LDR", "RFE", "TMP", "WIG", "WIR", "WIND_U", and "WIND_V".

Usage

get_meteo_available(env_data)

Value

A vector of available meteorological components.

Arguments

env_data

Data table containing environmental data. Must contain column "Komponente"

Examples

Run this code
# Example environmental data
env_data <- data.table::data.table(
  Komponente = c("TMP", "NO2", "GLO", "WIR"),
  Wert = c(25, 40, 300, 50),
  date = as.POSIXct(c(
    "2023-01-01 08:00:00", "2023-01-01 09:00:00",
    "2023-01-01 10:00:00", "2023-01-01 11:00:00"
  ))
)
# Get available meteorological components
meteo_components <- get_meteo_available(env_data)
print(meteo_components)

Run the code above in your browser using DataLab